@@ -86,7 +86,7 @@ long_to_wide_converter <- function(
   data %<>%
     ungroup() %>%
     nest_by(.rowid, .key = "nested_data") %>%
-    filter(sum(is.na(nested_data)) == 0L) %>%
+    filter(!anyNA(nested_data)) %>%
     tidyr::unnest(cols = nested_data)
 
   # convert to wide?
